@@ -1,7 +1,6 @@
 'use strict';
 
-require('./support');
-const assert = require('assert').strict;
+const assert = require('assert');
 const match = require('./support/match');
 const { isMatch, makeRe } = require('..');
 
@@ -10,8 +9,8 @@ const { isMatch, makeRe } = require('..');
  */
 
 describe('extglobs', () => {
-  it('should throw on imbalanced sets when `options.strictBrackets` is true', () => {
-    let opts = { strictBrackets: true };
+  it('should throw on imbalanced sets when `optionsBrackets` is true', () => {
+    const opts = { strictBrackets: true };
     assert.throws(() => makeRe('a(b', opts), /Missing closing: "\)"/i);
     assert.throws(() => makeRe('a)b', opts), /Missing opening: "\("/i);
   });
@@ -26,7 +25,7 @@ describe('extglobs', () => {
   });
 
   it('should not convert capture groups to extglobs', () => {
-    assert.equal(makeRe('c!(?:foo)?z').source, '^(?:c!(?:foo)?z)$');
+    assert.strictEqual(makeRe('c!(?:foo)?z').source, '^(?:c!(?:foo)?z)$');
     assert(!isMatch('c/z', 'c!(?:foo)?z'));
     assert(isMatch('c!fooz', 'c!(?:foo)?z'));
     assert(isMatch('c!z', 'c!(?:foo)?z'));
@@ -35,7 +34,6 @@ describe('extglobs', () => {
   describe('negation', () => {
     it('should support negation extglobs as the entire pattern', () => {
       assert(!isMatch('abc', '!(abc)'));
-
       assert(!isMatch('a', '!(a)'));
       assert(isMatch('aa', '!(a)'));
       assert(isMatch('b', '!(a)'));
@@ -45,7 +43,6 @@ describe('extglobs', () => {
       assert(isMatch('aac', 'a!(b)c'));
       assert(!isMatch('abc', 'a!(b)c'));
       assert(isMatch('acc', 'a!(b)c'));
-
       assert(isMatch('abz', 'a!(z)'));
       assert(!isMatch('az', 'a!(z)'));
     });
@@ -273,6 +270,12 @@ describe('extglobs', () => {
       assert(isMatch('aa.md', '?(a|aa|b).md'));
       assert(isMatch('ab.md', '?(a|ab|b).md'));
       assert(isMatch('b.md', '?(a|ab|b).md'));
+
+      // see https://github.com/micromatch/micromatch/issues/186
+      assert(isMatch('ab', '+(a)?(b)'));
+      assert(isMatch('aab', '+(a)?(b)'));
+      assert(isMatch('aa', '+(a)?(b)'));
+      assert(isMatch('a', '+(a)?(b)'));
     });
   });
 
@@ -713,26 +716,26 @@ describe('extglobs', () => {
   // these are not extglobs, and do not need to pass, but they are included
   // to test integration with other features
   it('should support regex characters', () => {
-    let fixtures = ['a c', 'a.c', 'a.xy.zc', 'a.zc', 'a123c', 'a1c', 'abbbbc', 'abbbc', 'abbc', 'abc', 'abq', 'axy zc', 'axy', 'axy.zc', 'axyzc'];
+    const fixtures = ['a c', 'a.c', 'a.xy.zc', 'a.zc', 'a123c', 'a1c', 'abbbbc', 'abbbc', 'abbc', 'abc', 'abq', 'axy zc', 'axy', 'axy.zc', 'axyzc'];
 
     if (process.platform !== 'win32') {
-      assert.deepEqual(match(['a\\b', 'a/b', 'ab'], 'a/b'), ['a/b']);
+      assert.deepStrictEqual(match(['a\\b', 'a/b', 'ab'], 'a/b'), ['a/b']);
     }
 
-    assert.deepEqual(match(['a/b', 'ab'], 'a/b'), ['a/b']);
-    assert.deepEqual(match(fixtures, 'ab?bc'), ['abbbc']);
-    assert.deepEqual(match(fixtures, 'ab*c'), ['abbbbc', 'abbbc', 'abbc', 'abc']);
-    assert.deepEqual(match(fixtures, 'a+(b)bc'), ['abbbbc', 'abbbc', 'abbc']);
-    assert.deepEqual(match(fixtures, '^abc$'), []);
-    assert.deepEqual(match(fixtures, 'a.c'), ['a.c']);
-    assert.deepEqual(match(fixtures, 'a.*c'), ['a.c', 'a.xy.zc', 'a.zc']);
-    assert.deepEqual(match(fixtures, 'a*c'), ['a c', 'a.c', 'a.xy.zc', 'a.zc', 'a123c', 'a1c', 'abbbbc', 'abbbc', 'abbc', 'abc', 'axy zc', 'axy.zc', 'axyzc']);
-    assert.deepEqual(match(fixtures, 'a[\\w]+c'), ['a123c', 'a1c', 'abbbbc', 'abbbc', 'abbc', 'abc', 'axyzc'], 'Should match word characters');
-    assert.deepEqual(match(fixtures, 'a[\\W]+c'), ['a c', 'a.c'], 'Should match non-word characters');
-    assert.deepEqual(match(fixtures, 'a[\\d]+c'), ['a123c', 'a1c'], 'Should match numbers');
-    assert.deepEqual(match(['foo@#$%123ASD #$$%^&', 'foo!@#$asdfl;', '123'], '[\\d]+'), ['123']);
-    assert.deepEqual(match(['a123c', 'abbbc'], 'a[\\D]+c'), ['abbbc'], 'Should match non-numbers');
-    assert.deepEqual(match(['foo', ' foo '], '(f|o)+\\b'), ['foo'], 'Should match word boundaries');
+    assert.deepStrictEqual(match(['a/b', 'ab'], 'a/b'), ['a/b']);
+    assert.deepStrictEqual(match(fixtures, 'ab?bc'), ['abbbc']);
+    assert.deepStrictEqual(match(fixtures, 'ab*c'), ['abbbbc', 'abbbc', 'abbc', 'abc']);
+    assert.deepStrictEqual(match(fixtures, 'a+(b)bc'), ['abbbbc', 'abbbc', 'abbc']);
+    assert.deepStrictEqual(match(fixtures, '^abc$'), []);
+    assert.deepStrictEqual(match(fixtures, 'a.c'), ['a.c']);
+    assert.deepStrictEqual(match(fixtures, 'a.*c'), ['a.c', 'a.xy.zc', 'a.zc']);
+    assert.deepStrictEqual(match(fixtures, 'a*c'), ['a c', 'a.c', 'a.xy.zc', 'a.zc', 'a123c', 'a1c', 'abbbbc', 'abbbc', 'abbc', 'abc', 'axy zc', 'axy.zc', 'axyzc']);
+    assert.deepStrictEqual(match(fixtures, 'a[\\w]+c'), ['a123c', 'a1c', 'abbbbc', 'abbbc', 'abbc', 'abc', 'axyzc'], 'Should match word characters');
+    assert.deepStrictEqual(match(fixtures, 'a[\\W]+c'), ['a c', 'a.c'], 'Should match non-word characters');
+    assert.deepStrictEqual(match(fixtures, 'a[\\d]+c'), ['a123c', 'a1c'], 'Should match numbers');
+    assert.deepStrictEqual(match(['foo@#$%123ASD #$$%^&', 'foo!@#$asdfl;', '123'], '[\\d]+'), ['123']);
+    assert.deepStrictEqual(match(['a123c', 'abbbc'], 'a[\\D]+c'), ['abbbc'], 'Should match non-numbers');
+    assert.deepStrictEqual(match(['foo', ' foo '], '(f|o)+\\b'), ['foo'], 'Should match word boundaries');
   });
 });
 
