@@ -3,7 +3,7 @@
 require('mocha');
 const assert = require('assert').strict;
 const match = require('./support/match');
-const { isMatch, makeRe } = require('..');
+const { isMatch } = require('..');
 
 describe('stars', () => {
   describe('issue related', () => {
@@ -15,9 +15,33 @@ describe('stars', () => {
     });
 
     it('should regard non-exclusive double-stars as single stars', () => {
+      const fixtures = ['a', 'a/', 'a/a', 'a/a/', 'a/a/a', 'a/a/a/', 'a/a/a/a', 'a/a/a/a/', 'a/a/a/a/a', 'a/a/a/a/a/', 'a/a/b', 'a/a/b/', 'a/b', 'a/b/', 'a/b/c/.d/e/', 'a/c', 'a/c/', 'a/b', 'a/x/', 'b', 'b/', 'x/y', 'x/y/', 'z/z', 'z/z/'];
+
+      assert.deepEqual(match(fixtures, '**a/a/*/'), ['a/a/a/', 'a/a/b/']);
       assert(!isMatch('aaa/bba/ccc', 'aaa/**ccc'));
       assert(!isMatch('aaa/bba/ccc', 'aaa/**z'));
       assert(isMatch('aaa/bba/ccc', 'aaa/**b**/ccc'));
+      assert(!isMatch('a/b/c', '**c'));
+      assert(!isMatch('a/b/c', 'a/**c'));
+      assert(!isMatch('a/b/c', 'a/**z'));
+      assert(!isMatch('a/b/c/b/c', 'a/**b**/c'));
+      assert(!isMatch('a/b/c/d/e.js', 'a/b/c**/*.js'));
+      assert(isMatch('a/b/c/b/c', 'a/**/b/**/c'));
+      assert(isMatch('a/aba/c', 'a/**b**/c'));
+      assert(isMatch('a/b/c', 'a/**b**/c'));
+      assert(isMatch('a/b/c/d.js', 'a/b/c**/*.js'));
+    });
+
+    it('should support globstars followed by braces', () => {
+      assert(isMatch('a/b/c/d/e/z/foo.md', 'a/**/c/**{,(/z|/x)}/*.md'));
+      assert(isMatch('a/b/c/d/e/z/foo.md', 'a/**{,(/x|/z)}/*.md'));
+    });
+
+    it('should support globstars followed by braces with nested extglobs', () => {
+      assert(isMatch('/x/foo.md', '@(/x|/z)/*.md'));
+      assert(isMatch('/z/foo.md', '@(/x|/z)/*.md'));
+      assert(isMatch('a/b/c/d/e/z/foo.md', 'a/**/c/**@(/z|/x)/*.md'));
+      assert(isMatch('a/b/c/d/e/z/foo.md', 'a/**@(/x|/z)/*.md'));
     });
 
     it('should support multiple globstars in one pattern', () => {
@@ -35,7 +59,7 @@ describe('stars', () => {
     });
 
     it('should respect trailing slashes on paterns', () => {
-      let fixtures = ['a', 'a/', 'a/a', 'a/a/', 'a/a/a', 'a/a/a/', 'a/a/a/a', 'a/a/a/a/', 'a/a/a/a/a', 'a/a/a/a/a/', 'a/a/b', 'a/a/b/', 'a/b', 'a/b/', 'a/b/c/.d/e/', 'a/c', 'a/c/', 'a/b', 'a/x/', 'b', 'b/', 'x/y', 'x/y/', 'z/z', 'z/z/'];
+      const fixtures = ['a', 'a/', 'a/a', 'a/a/', 'a/a/a', 'a/a/a/', 'a/a/a/a', 'a/a/a/a/', 'a/a/a/a/a', 'a/a/a/a/a/', 'a/a/b', 'a/a/b/', 'a/b', 'a/b/', 'a/b/c/.d/e/', 'a/c', 'a/c/', 'a/b', 'a/x/', 'b', 'b/', 'x/y', 'x/y/', 'z/z', 'z/z/'];
 
       assert.deepEqual(match(fixtures, '**/*/a/'), ['a/a/', 'a/a/a/', 'a/a/a/a/', 'a/a/a/a/a/']);
       assert.deepEqual(match(fixtures, '**/*/a/*/'), ['a/a/a/', 'a/a/a/a/', 'a/a/a/a/a/', 'a/a/b/']);
@@ -52,7 +76,7 @@ describe('stars', () => {
     });
 
     it('should match literal globstars when stars are escaped', () => {
-      let fixtures = ['.md', '**a.md', '**.md', '.md', '**'];
+      const fixtures = ['.md', '**a.md', '**.md', '.md', '**'];
       assert.deepEqual(match(fixtures, '\\*\\**.md'), ['**a.md', '**.md']);
       assert.deepEqual(match(fixtures, '\\*\\*.md'), ['**.md']);
     });
@@ -286,7 +310,7 @@ describe('stars', () => {
     });
 
     it('should match leading dots when defined in pattern', () => {
-      let fixtures = ['.gitignore', 'a/b/z/.dotfile', 'a/b/z/.dotfile.md', 'a/b/z/.dotfile.md', 'a/b/z/.dotfile.md'];
+      const fixtures = ['.gitignore', 'a/b/z/.dotfile', 'a/b/z/.dotfile.md', 'a/b/z/.dotfile.md', 'a/b/z/.dotfile.md'];
       assert(!isMatch('.gitignore', 'a/**/z/*.md'));
       assert(!isMatch('a/b/z/.dotfile', 'a/**/z/*.md'));
       assert(!isMatch('a/b/z/.dotfile.md', '**/c/.*.md'));
