@@ -2,9 +2,14 @@
 
 require('mocha');
 const assert = require('assert').strict;
+const support = require('./support');
 const { isMatch } = require('..');
 
 describe('slash handling - posix', () => {
+  before(() => support.resetPathSep());
+  after(() => support.resetPathSep());
+  afterEach(() => support.resetPathSep());
+
   it('should match a literal string', () => {
     assert(!isMatch('a/a', '(a/b)'));
     assert(isMatch('a/b', '(a/b)'));
@@ -1149,7 +1154,7 @@ describe('slash handling - posix', () => {
   });
 
   it('should match paths with leading `./` when pattern has `./`', () => {
-    let format = str => str.replace(/^\.\//, '');
+    const format = str => str.replace(/^\.\//, '');
     assert(!isMatch('./a/b/c/d/e/z/c.md', './a/**/j/**/z/*.md', { format }));
     assert(!isMatch('./a/b/c/j/e/z/c.txt', './a/**/j/**/z/*.md', { format }));
     assert(isMatch('./a/b/c/d/e/j/n/p/o/z/c.md', './a/**/j/**/z/*.md', { format }));
