@@ -8,9 +8,11 @@ const { isMatch, makeRe } = require('..');
 describe('slash handling - windows', () => {
   beforeEach(() => support.windowsPathSep());
   afterEach(() => support.resetPathSep());
+  before(() => support.resetPathSep());
+  after(() => support.resetPathSep());
 
   it('should match absolute windows paths with regex from makeRe', () => {
-    let regex = makeRe('**/path/**', { windows: true });
+    const regex = makeRe('**/path/**', { windows: true });
     assert(regex.test('C:\\Users\\user\\Projects\\project\\path\\image.jpg'));
   });
 
